from distutils.core import setup

setup(
        name = 'outcry',
        packages = ['outcry'],
        version = '0.1.0',
        description = 'Parse and render REST documents using representers',
        author = 'Kareem Kwong',
        author_email = 'kareem.kwong@gmail.com',
        url = 'https://github.com/kwngo/outcry',
        download_url = 'https://github.com/kwngo/outcry/archive/0.1.0.tar.gz',
        keywords = ['json', 'parsing', 'render'],
        classifiers = []
        )
